## kube-workload-restarter

[![Package publish](https://github.com/andreacioni/kube-workload-restarter/actions/workflows/main.yml/badge.svg)](https://github.com/andreacioni/kube-workload-restarter/actions/workflows/main.yml)
